==> open-xchange-core_7.10.5.orig.tar.bz2: open-xchange-core-7.10.5/com.openexchange.server/src/com/openexchange/groupware/update/internal/DependencyChecker.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.groupware.update.internal;

import com.openexchange.groupware.update.UpdateTaskV2;

/**
 * Checks if the dependencies of an update task are fulfilled.
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public interface DependencyChecker {

    /**
     * Checks if the current task can be executed next. The sorter iterates across all checkers so every checker has to return
     * <code>false</code> if prerequisites are not fulfilled.
     * @param task Current task to check.
     * @param executed list of tasks that are already executed on the schema.
     * @param enqueued list of tasks that are scheduled to be executed before the current task.
     * @param toExecute list of tasks that have to be executed.
     * @return <code>true</code> if the current task can be now scheduled for execution.
     */
    boolean check(UpdateTaskV2 task, String[] executed, UpdateTaskV2[] enqueued, UpdateTaskV2[] toExecute);

}

==> open-xchange-core_7.10.6.orig.tar.bz2: open-xchange-core-7.10.6/com.openexchange.server/src/com/openexchange/groupware/update/internal/DependencyChecker.java <==
/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.groupware.update.internal;

import com.openexchange.groupware.update.NamesOfExecutedTasks;
import com.openexchange.groupware.update.UpdateTaskV2;

/**
 * Checks if the dependencies of an update task are fulfilled.
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public interface DependencyChecker {

    /**
     * Checks if the current task can be executed next. The sorter iterates across all checkers so every checker has to return
     * <code>false</code> if prerequisites are not fulfilled.
     * @param task Current task to check.
     * @param executed list of tasks that are already executed on the schema.
     * @param enqueued list of tasks that are scheduled to be executed before the current task.
     * @param toExecute list of tasks that have to be executed.
     * @return <code>true</code> if the current task can be now scheduled for execution.
     */
    boolean check(UpdateTaskV2 task, NamesOfExecutedTasks executed, UpdateTaskV2[] enqueued, UpdateTaskV2[] toExecute);

}
